close all
[bvp,info]=fc_vfemp1.samples.setBVPStationaryConvectionDiffusion2D01(30,'verbose',1);

fprintf('3. Solving 2D stationary convection-diffusion BVP\n')
u=bvp.solve(); 

fprintf('4. Graphic representations\n');
options=fc_tools.graphics.DisplayFigures('nfig',7);
interpreter=@(x) fc_tools.graphics.interpreter(x);
isOctave=fc_tools.comp.isOctave();
%disp('Press a key');pause

Th=bvp.Th;
figure(1)
Th.plotmesh('legend',true)
set(legend(),options.legend{:})
hold on,axis off,axis image
Th.plotmesh('d',1,'Linewidth',2,'Color','k')

figure(2)
Th.plotmesh('Color',0.85*[1,1,1])
hold on,axis off,axis image
Th.plotmesh('d',1,'Linewidth',2,'legend',true)
set(legend(),options.legend{:})

figure(3)
Th.plot(u)
axis off;axis image,shading interp
title(interpreter(sprintf('Numerical solution ( $n_q=%d$, $n_{me}=%d$ )',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});
h=colorbar();
set(get(h,'title'),'string',interpreter('$u$'),options.interpreter{:},options.title{:})
set(h,options.colorbar{:})

figure(4)
Th.plot(u)
hold on,axis off,axis image
Th.plotiso(u,'isorange',0,'Color','w','Linewidth',1.5);
shading interp
title(interpreter(sprintf('Numerical solution ( $n_q=%d$, $n_{me}=%d$ )',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});
h=colorbar();
set(get(h,'title'),'string',interpreter('$u$'),options.interpreter{:},options.title{:})
set(h,options.colorbar{:})

figure(5)
Th.plot(u,'FaceAlpha',0.8);
hold on,axis off,axis image
if isOctave % FaceAlpha not implemented in Octave
  Th.plotiso(u,'niso',20,'Linewidth',1.5,'color','w');
  set(colorbar(),options.colorbar{:})
else
  [~,~,cax]=Th.plotiso(u,'niso',20,'Linewidth',1.5,'isocolorbar',true,'format','%.3f');
  set(cax,options.colorbar{:})
end
shading interp
title(interpreter(sprintf('Numerical solution ( $n_q=%d$, $n_{me}=%d$ )',Th.nq,Th.get_nme())),options.interpreter{:},options.title{:});

figure(6)
Th.plot(u,'FaceColor','interp','FaceAlpha',0.8,'EdgeColor','none');
hold on
if isOctave
  Th.plotiso(u,'niso',20,'Linewidth',1.5,'color','w');
  set(colorbar(),options.colorbar{:})
else
  [~,~,cax]=Th.plotiso(u,'niso',20,'Linewidth',1.5,'isocolorbar',true,'format','%.3f');
  set(cax,options.colorbar{:})
end
Th.plotiso(u,'isorange',0,'Color','k','Linewidth',1.5);
view(106,27)
xlabel('x'),ylabel('y'),zlabel('z')
set(gca,options.axes{:})

figure(7)
clf
V=Th.eval(info.V);
Th.plotVectorField(V,'colordata',u,'scale',0.005,'freq',1);
hold on,axis image, axis off
set(colorbar(),options.colorbar{:})
Th.plotmesh('d',1,'Color','k','Linewidth',2)
